==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_RE","Odp");
define("_SUBJECT","Temat");
define("_PRIVATEMESSAGES","Twoje prywatne wiadomoci");
define("_CHECKALL","Sprawd wszystkie");
define("_FROM","Od");
define("_DATE","Data");
define("_DONTHAVEMESSAGES","Nie masz adnych wiadomoci");
define("_NOTREAD","Nie czytana");
define("_MSGSTATUS","Status wiadomoci");
define("_PRIVATEMESSAGE","Wiadomo prywatna");
define("_INDEX","Indeks");
define("_SENT","Wysane");
define("_PREVIOUSMESSAGE","Poprzednia wiadomo");
define("_NEXTMESSAGE","Nastpna wiadomo");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","O wysyaniu");
define("_ALLREGCANPOST","Wszyscy zarejestrowani uytkownicy mog wysya wiadomoci prywatne");
define("_TO","Do");
define("_MESSAGEICON","Ikona wiadomoci");
define("_MESSAGE","Wiadomo");
define("_HTML","HTML");
define("_PMON","Wcz");
define("_PMOFF","Wycz");
define("_BBCODE","BBCode");
define("_WROTE","napisa(a)");
define("_OPTIONS","Opcje");
define("_HTMLDISSABLE","Wycz HTML w tej wiadomoci");
define("_BBCODEDISSABLE","Wycz <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> w tej wiadomoci");
define("_SMILEDISSABLE","Wycz <a href=\"bb_smilies.php\" target=\"_blank\"><i>smilies</i></a> w tej wiadomoci");
define("_CANCELREPLY","Anuluj odpowied");
define("_CANCELSEND","Anuluj wysyanie");
define("_CLEAR","Wyczy");
define("_SUBMIT","Wylij");
define("_USERNOTINDB","Wybrany uytkownik nie istnieje w bazie.");
define("_CHECKNAMEANDTRY","Prosz sprawdzi nazw i sprbowa ponownie.");
define("_MSGPOSTED","Twoja wiadomo zostaa wysana.");
define("_RETURNTOPMSG","Moesz klikn tutaj, aby zaadowa powtrnie Twoje prywatne wiadomoci.");
define("_MSGDELETED","Twoja wiadomo zostaa skasowana.");
define("_BBGO","id");
define("_BBNEWPMSG","Nowe wiadomoci");
define("_BBNONEWPMSG","Nie ma nowych wiadomoci");
define("_BBTOTALPMSG","Suma wiadomoci");
define("_BBEMPTYPMSG","Nie masz adnych wiadomoci");
define("_BBLOGIN","Zaloguj si by sprawdzi prywatne wiadomoci");
define("_BBPMSG","Wiadomo prywatna");
define("_BBINBOX","Skrzynka odbiorcza");
define("_BBSELECTFORUM","Wybierz Forum");
define("_BBNOFORUM","Nie ma wicej Forum");
define("_BBBANNED","Zbanowany");
define("_CLICKSMILEBUTTONS","Kliknij na buki by wstawi je do wiadomoci:");
define("_CLICKCODEBUTTONS","Kliknij ponisze przyciski by doda BBCode do Twojej wiadomoci:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_RE","Odp");
define("_SUBJECT","Temat");
define("_PRIVATEMESSAGES","Twoje prywatne wiadomoci");
define("_CHECKALL","Sprawd wszystkie");
define("_FROM","Od");
define("_DATE","Data");
define("_DONTHAVEMESSAGES","Nie masz adnych wiadomoci");
define("_NOTREAD","Nie czytana");
define("_MSGSTATUS","Status wiadomoci");
define("_PRIVATEMESSAGE","Wiadomo prywatna");
define("_INDEX","Indeks");
define("_SENT","Wysane");
define("_PREVIOUSMESSAGE","Poprzednia wiadomo");
define("_NEXTMESSAGE","Nastpna wiadomo");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","O wysyaniu");
define("_ALLREGCANPOST","Wszyscy zarejestrowani uytkownicy mog wysya wiadomoci prywatne");
define("_TO","Do");
define("_MESSAGEICON","Ikona wiadomoci");
define("_MESSAGE","Wiadomo");
define("_HTML","HTML");
define("_PMON","Wcz");
define("_PMOFF","Wycz");
define("_BBCODE","BBCode");
define("_WROTE","napisa(a)");
define("_OPTIONS","Opcje");
define("_HTMLDISSABLE","Wycz HTML w tej wiadomoci");
define("_BBCODEDISSABLE","Wycz <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> w tej wiadomoci");
define("_SMILEDISSABLE","Wycz <a href=\"bb_smilies.php\" target=\"_blank\"><i>smilies</i></a> w tej wiadomoci");
define("_CANCELREPLY","Anuluj odpowied");
define("_CANCELSEND","Anuluj wysyanie");
define("_CLEAR","Wyczy");
define("_SUBMIT","Wylij");
define("_USERNOTINDB","Wybrany uytkownik nie istnieje w bazie.");
define("_CHECKNAMEANDTRY","Prosz sprawdzi nazw i sprbowa ponownie.");
define("_MSGPOSTED","Twoja wiadomo zostaa wysana.");
define("_RETURNTOPMSG","Moesz klikn tutaj, aby zaadowa powtrnie Twoje prywatne wiadomoci.");
define("_MSGDELETED","Twoja wiadomo zostaa skasowana.");
define("_BBGO","id");
define("_BBNEWPMSG","Nowe wiadomoci");
define("_BBNONEWPMSG","Nie ma nowych wiadomoci");
define("_BBTOTALPMSG","Suma wiadomoci");
define("_BBEMPTYPMSG","Nie masz adnych wiadomoci");
define("_BBLOGIN","Zaloguj si by sprawdzi prywatne wiadomoci");
define("_BBPMSG","Wiadomo prywatna");
define("_BBINBOX","Skrzynka odbiorcza");
define("_BBSELECTFORUM","Wybierz Forum");
define("_BBNOFORUM","Nie ma wicej Forum");
define("_BBBANNED","Zbanowany");
define("_CLICKSMILEBUTTONS","Kliknij na buki by wstawi je do wiadomoci:");
define("_CLICKCODEBUTTONS","Kliknij ponisze przyciski by doda BBCode do Twojej wiadomoci:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>
